#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yaml
version:              0.11.5.0
visibility:           public
id:                   yaml-0.11.5.0-7UJv2Fq2f113FoCoCodYb3
key:                  yaml-0.11.5.0-7UJv2Fq2f113FoCoCodYb3
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  b090c9c7ef617d3223e875ff82ed23dd
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-8.10.5/site-local/yaml-0.11.5.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/yaml-0.11.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/yaml-0.11.5.0
hs-libraries:         HSyaml-0.11.5.0-7UJv2Fq2f113FoCoCodYb3
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    bytestring-0.10.12.0 conduit-1.3.4.1-GHgRKpknFuqDscwzVojbiE
    containers-0.6.4.1 directory-1.3.6.0 filepath-1.4.2.1
    libyaml-0.1.2-6Nuu7YGrPFbiflwWOt8lk mtl-2.2.2
    resourcet-1.2.4.2-7etOfd8fePh2l91avxjTIe
    scientific-0.3.7.0-Fi0gRGhsiJ35wgbCjOXuHX template-haskell-2.16.0.0
    text-1.2.4.1 transformers-0.5.6.2
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

